<?php

namespace Litecms\Faucetlevel\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Faucetlevel\Models\Faucetlevel;

class FaucetlevelPolicy
{

    /**
     * Determine if the given user can view the faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function view(UserPolicy $user, Faucetlevel $faucetlevel)
    {
        if ($user->canDo('faucetlevel.faucetlevel.view') && $user->isAdmin()) {
            return true;
        }

        return $faucetlevel->user_id == user_id() && $faucetlevel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faucetlevel.faucetlevel.create');
    }

    /**
     * Determine if the given user can update the given faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function update(UserPolicy $user, Faucetlevel $faucetlevel)
    {
        if ($user->canDo('faucetlevel.faucetlevel.edit') && $user->isAdmin()) {
            return true;
        }

        return $faucetlevel->user_id == user_id() && $faucetlevel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Faucetlevel $faucetlevel)
    {
        return $faucetlevel->user_id == user_id() && $faucetlevel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Faucetlevel $faucetlevel)
    {
        if ($user->canDo('faucetlevel.faucetlevel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faucetlevel.
     *
     * @param UserPolicy $user
     * @param Faucetlevel $faucetlevel
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Faucetlevel $faucetlevel)
    {
        if ($user->canDo('faucetlevel.faucetlevel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
