<?php

namespace Litecms\Faucetlevel\Providers;

use Illuminate\Support\ServiceProvider;

class FaucetlevelServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'faucetlevel');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'faucetlevel');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.faucetlevel', function ($app) {
            return $this->app->make('Litecms\Faucetlevel\Faucetlevel');
        });

                // Bind Faucetlevel to repository
        $this->app->bind(
            'Litecms\Faucetlevel\Interfaces\FaucetlevelRepositoryInterface',
            \Litecms\Faucetlevel\Repositories\Eloquent\FaucetlevelRepository::class
        );

        $this->app->register(\Litecms\Faucetlevel\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Faucetlevel\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.faucetlevel'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/faucetlevel.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/faucetlevel')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/faucetlevel')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
